==> jc-1.4.0.tar.gz: javax/swing/JRootPane__24AccessibleJRootPane.h <==
// public class javax.swing.JRootPane$AccessibleJRootPane

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b2cd729d8d354462 javax_swing_JRootPane__24AccessibleJRootPane

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_
#define _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$refs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object	_jc_javax_swing_JRootPane__24AccessibleJRootPane$object;

typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct	_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype;

// Class fields structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields;

// Constructors
extern void _jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *);
};

// Vtable
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods	javax_swing_JRootPane__24AccessibleJRootPane;
};

// Vtype
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype {
	_jc_type			type;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$refs {
    _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs	javax_swing_JRootPane__24AccessibleJRootPane;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs	javax_swing_JRootPane__24AccessibleJRootPane;
};

// Object instance structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object {
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype	*vtype;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype _jc_javax_swing_JRootPane__24AccessibleJRootPane$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRootPane__24AccessibleJRootPane, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_object;

#endif	/* _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_ */

==> jc-1.4.6.tar.gz: javax/swing/JRootPane__24AccessibleJRootPane.h <==
// public class javax.swing.JRootPane$AccessibleJRootPane

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b2cd729d8d354462 javax_swing_JRootPane__24AccessibleJRootPane

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_
#define _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$refs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs	_jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs;
typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object	_jc_javax_swing_JRootPane__24AccessibleJRootPane$object;

typedef struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct	_jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable;
typedef const struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype;

// Class fields structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JRootPane__24AccessibleJRootPane$fields_struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_fields;

// Constructors
extern void _jc_javax_swing_JRootPane__24AccessibleJRootPane$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JRootPane__24AccessibleJRootPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JRootPane__24AccessibleJRootPane$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vmethods	javax_swing_JRootPane__24AccessibleJRootPane;
};

// Vtype
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype {
	_jc_type			type;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$refs {
    _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_refs	javax_swing_JRootPane__24AccessibleJRootPane;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JRootPane__24AccessibleJRootPane$sub_nonrefs	javax_swing_JRootPane__24AccessibleJRootPane;
};

// Object instance structure
struct _jc_javax_swing_JRootPane__24AccessibleJRootPane$object {
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype	*vtype;
	_jc_javax_swing_JRootPane__24AccessibleJRootPane$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JRootPane__24AccessibleJRootPane$vtype _jc_javax_swing_JRootPane__24AccessibleJRootPane$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JRootPane__24AccessibleJRootPane, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JRootPane__24AccessibleJRootPane$class_object;

#endif	/* _JC_javax_swing_JRootPane__24AccessibleJRootPane_H_ */
